## /Library/Frameworks/Python.framework/Versions/3.5/lib/python3.5/site-packages/rp/r.py.rprc.py
## This is the rprc file. Like .bashrc, or .vimrc, this file is run each time you boot rp from the command line.
## Feel free to commment/uncomment any of the lines here, or to add your own. This file is preserved when you update rp.

## Import the rp library's whole namespace. It's not nessecary, but it exposes a lot of useful functions without
#from rp import *

## Set the terminal's cursor to the shape of a line, instead of a block. I personally prefer this, but I've commented out because I don't know if you'd like it.
#set_cursor_to_bar()

from rp import *
